@@ -8,7 +8,7 @@ from .modules import *
 from re import fullmatch
 from http import HTTPStatus
 
-__version__ = '1.2.8.4'
+__version__ = '1.2.8.6'
 
 class PathMaker(dict):
     '''For storing and handling path mapping
@@ -63,40 +63,6 @@ class PyWebHost(socketserver.ThreadingMixIn, socketserver.TCPServer,):
         """Handle an error gracefully. """
         super().handle_error(socket_,client_address)
 
-    def handle_request_blocking(self):
-        """Handle one request"""
-        try:
-            socket_ , client_address = self.get_request()
-        except OSError:
-            return
-
-        if self.verify_request(socket_, client_address):
-            try:
-                self.process_request(socket_, client_address)
-            except Exception as e:
-                self.handle_error(socket_, client_address , e)
-                self.shutdown_request(socket_)
-            except:
-                self.shutdown_request(socket_)
-                raise
-        else:
-            self.shutdown_request(socket_)
-
-    def serve_forever(self):
-            """Handle one request at a time - Respects self.timeout
-
-            The poll function was no longer needed as blocking is no longer an issuse
-            as only threading requests are considered            
-            """
-            self._BaseServer__is_shut_down.clear()
-            try:                
-                while not self._BaseServer__shutdown_request:                                        
-                    if self._BaseServer__shutdown_request:
-                        break                    
-                    self.handle_request_blocking()                        
-            finally:
-                self._BaseServer__is_shut_down.set()
-
     def handle(self, request : Request):
         '''
         Maps the request with the `PathMaker`
@@ -124,7 +90,9 @@ class PyWebHost(socketserver.ThreadingMixIn, socketserver.TCPServer,):
         e.g:
 
             @server.route('/')
-                def index():lambda a:SendFile('index.html')
+            
+            def index(server : PyWebHost,request : Request,content):
+                request.send_response(200)
         '''
         def wrapper(method):
             self.paths[pattern] = method
