@@ -103,7 +103,7 @@ class Request(StreamRequestHandler):
         '''The `server`,which is what instantlizes this handler,must have `handle` method
         which takes 1 argument (for the handler itself) 
         '''
-        self.logger = logging.getLogger('Request')
+        self.logger = logging.getLogger('PyWebHost')
         '''These values are from the server'''
         # The version of the HTTP protocol we support.
         # Set this to HTTP/1.1 to enable automatic keepalive
